export class BatchDrawer {
    constructor(renderer) {
        this.renderer = renderer;
    }
    draw() {
        const { renderer, _batchFactory: batchFactory, _geometryFactory: geometryFactory, _indexProperty: indexProperty, } = this.renderer;
        const batchList = batchFactory.access();
        const batchCount = batchFactory.size();
        const geom = geometryFactory.build();
        const { gl } = renderer;
        batchList[0].upload(renderer);
        renderer.shader.bind(this.renderer._shader, false);
        renderer.geometry.bind(geom);
        for (let i = 0; i < batchCount; i++) {
            const batch = batchList[i];
            batch.upload(renderer);
            renderer.shader.bind(this.renderer._shader, false);
            if (indexProperty) {
                gl.drawElements(gl.TRIANGLES, batch.$indexCount, gl.UNSIGNED_SHORT, batch.geometryOffset * 2);
            }
            else {
                gl.drawArrays(gl.TRIANGLES, batch.geometryOffset, batch.$vertexCount);
            }
            batch.reset();
        }
        geometryFactory.release(geom);
    }
}
//# sourceMappingURL=BatchDrawer.js.map