import { AttributeRedirect } from './redirects/AttributeRedirect';
import * as PIXI from 'pixi.js';
import BatchRenderer from './BatchRenderer';
export declare class BatchGeometry extends PIXI.Geometry {
    attribBuffer: PIXI.Buffer;
    indexBuffer: PIXI.Buffer;
    constructor(attributeRedirects: AttributeRedirect[], hasIndex: boolean, texIDAttrib: string, texturesPerObject: number, inBatchIDAttrib: string, uniformIDAttrib: string, masterIDAttrib: string, attributeBuffer?: PIXI.Buffer, indexBuffer?: PIXI.Buffer);
}
export declare abstract class IBatchGeometryFactory {
    protected _renderer: BatchRenderer;
    constructor(renderer: BatchRenderer);
    abstract init(verticesBatched: number, indiciesBatched: number): void;
    abstract append(displayObject: PIXI.DisplayObject, batch: any): void;
    abstract build(): PIXI.Geometry;
    abstract release(geom: PIXI.Geometry): void;
}
export declare class BatchGeometryFactory extends IBatchGeometryFactory {
    _targetCompositeAttributeBuffer: PIXI.ViewableBuffer;
    _targetCompositeIndexBuffer: Uint16Array;
    _aIndex: number;
    _iIndex: number;
    _attribRedirects: AttributeRedirect[];
    _indexProperty: string;
    _vertexCountProperty: string | number;
    _vertexSize: number;
    _texturesPerObject: number;
    _textureProperty: string;
    _texIDAttrib: string;
    _inBatchIDAttrib: string;
    _inBatchID: number;
    _uniformIDAttrib: string;
    _uniformID: number;
    _masterIDAttrib: string;
    protected _texID: number | number[];
    protected _aBuffers: PIXI.ViewableBuffer[];
    protected _iBuffers: Uint16Array[];
    protected _geometryPool: Array<PIXI.Geometry>;
    _geometryMerger: (displayObject: PIXI.DisplayObject, factory: BatchGeometryFactory) => void;
    constructor(renderer: BatchRenderer);
    init(verticesBatched: number, indiciesBatched?: number): void;
    append(targetObject: PIXI.DisplayObject, batch_: any): void;
    build(): PIXI.Geometry;
    release(geom: PIXI.Geometry): void;
    protected get geometryMerger(): (displayObject: PIXI.DisplayObject, factory: BatchGeometryFactory) => void;
    protected set geometryMerger(func: (displayObject: PIXI.DisplayObject, factory: BatchGeometryFactory) => void);
    protected getAttributeBuffer(size: number): PIXI.ViewableBuffer;
    protected getIndexBuffer(size: number): Uint16Array;
}
export default BatchGeometryFactory;
