import { StdBatchFactory } from './StdBatchFactory';
import { BatchGeometryFactory } from './BatchGeometryFactory';
import * as PIXI from 'pixi.js';
import { AttributeRedirect } from './redirects/AttributeRedirect';
import { BatchDrawer } from './BatchDrawer';
import { UniformRedirect } from './redirects/UniformRedirect';
export interface IBatchRendererOptions {
    attribSet: AttributeRedirect[];
    indexProperty: string;
    vertexCountProperty?: string | number;
    textureProperty: string;
    texturesPerObject?: number;
    texIDAttrib: string;
    inBatchIDAttrib?: string;
    masterIDAttrib?: string;
    stateFunction?: (renderer: PIXI.DisplayObject) => PIXI.State;
    shaderFunction: (renderer: BatchRenderer) => PIXI.Shader;
    BatchFactoryClass?: typeof StdBatchFactory;
    BatchGeometryFactoryClass?: typeof BatchGeometryFactory;
    BatchDrawerClass?: typeof BatchDrawer;
    uniformSet?: UniformRedirect[];
    uniformIDAttrib?: string;
}
export declare class BatchRenderer extends PIXI.ObjectRenderer {
    readonly _attribRedirects: AttributeRedirect[];
    readonly _indexProperty: string;
    readonly _vertexCountProperty: string | number;
    readonly _textureProperty: string;
    readonly _texturesPerObject: number;
    readonly _texIDAttrib: string;
    readonly _inBatchIDAttrib: string;
    readonly _stateFunction: Function;
    readonly _shaderFunction: Function;
    readonly _uniformRedirects: UniformRedirect[];
    readonly _uniformIDAttrib: string;
    readonly _masterIDAttrib: string;
    _batchFactory: StdBatchFactory;
    _geometryFactory: BatchGeometryFactory;
    _drawer: BatchDrawer;
    _objectBuffer: PIXI.DisplayObject[];
    _bufferedVertices: number;
    _bufferedIndices: number;
    _shader: PIXI.Shader;
    MAX_TEXTURES: number;
    protected readonly _BatchFactoryClass: typeof StdBatchFactory;
    protected readonly _BatchGeometryFactoryClass: typeof BatchGeometryFactory;
    protected readonly _BatchDrawerClass: typeof BatchDrawer;
    protected readonly options: any;
    constructor(renderer: PIXI.Renderer, options: IBatchRendererOptions);
    contextChange(): void;
    start(): void;
    render(displayObject: PIXI.DisplayObject): void;
    flush(): void;
    stop(): void;
    protected _vertexCountFor(targetObject: PIXI.DisplayObject): number;
}
export default BatchRenderer;
