import { StdBatch } from './StdBatch';
export class StdBatchFactory {
    constructor(renderer) {
        this._renderer = renderer;
        this._state = null;
        this._textureCount = renderer._texturesPerObject;
        this._textureProperty = renderer._textureProperty;
        this._textureLimit = renderer.MAX_TEXTURES;
        this._textureBuffer = {};
        this._textureBufferLength = 0;
        this._textureIndexedBuffer = [];
        this._textureIndexMap = {};
        this._batchBuffer = [];
        this._batchPool = [];
        this._batchCount = 0;
        if (this._textureCount === 1) {
            this._putTexture = this._putSingleTexture;
        }
        else {
            this._putTexture = this._putAllTextures;
        }
    }
    put(targetObject, state) {
        if (!this._state) {
            this._state = state;
        }
        else if (this._state.data !== state.data) {
            return false;
        }
        if (!this._put(targetObject)) {
            return false;
        }
        if (this._textureCount > 0 && !this._putTexture(targetObject[this._textureProperty])) {
            return false;
        }
        this._batchBuffer.push(targetObject);
        return true;
    }
    build(geometryOffset) {
        const batch = this._nextBatch();
        batch.geometryOffset = geometryOffset;
        this._buildBatch(batch);
        this._state = null;
        this._batchBuffer = [];
        this._textureBuffer = {};
        this._textureIndexMap = {};
        this._textureBufferLength = 0;
        this._textureIndexedBuffer = [];
    }
    ready() {
        return this._batchBuffer.length === 0;
    }
    reset() {
        this._batchCount = 0;
    }
    access() {
        return this._batchPool;
    }
    size() {
        return this._batchCount;
    }
    _put(displayObject) {
        return true;
    }
    _newBatch() {
        return new StdBatch();
    }
    _nextBatch(geometryOffset) {
        if (this._batchCount === this._batchPool.length) {
            this._batchPool.push(this._newBatch());
        }
        const batch = this._batchPool[this._batchCount++];
        batch.reset();
        batch.geometryOffset = geometryOffset;
        return batch;
    }
    _buildBatch(batch) {
        batch.batchBuffer = this._batchBuffer;
        batch.textureBuffer = this._textureIndexedBuffer;
        batch.uidMap = this._textureIndexMap;
        batch.state = this._state;
    }
    _putSingleTexture(texture) {
        if ('baseTexture' in texture) {
            texture = texture.baseTexture;
        }
        const baseTexture = texture;
        if (this._textureBuffer[baseTexture.uid]) {
            return true;
        }
        else if (this._textureBufferLength + 1 <= this._textureLimit) {
            this._textureBuffer[baseTexture.uid] = texture;
            this._textureBufferLength += 1;
            const newLength = this._textureIndexedBuffer.push(baseTexture);
            const index = newLength - 1;
            this._textureIndexMap[baseTexture.uid] = index;
            return true;
        }
        return false;
    }
    _putAllTextures(textureArray) {
        let deltaBufferLength = 0;
        for (let i = 0; i < textureArray.length; i++) {
            const texture = (textureArray[i].baseTexture
                ? textureArray[i].baseTexture
                : textureArray[i]);
            if (!this._textureBuffer[texture.uid]) {
                ++deltaBufferLength;
            }
        }
        if (deltaBufferLength + this._textureBufferLength > this._textureLimit) {
            return false;
        }
        for (let i = 0; i < textureArray.length; i++) {
            const texture = textureArray[i].baseTexture
                ? textureArray[i].baseTexture
                : textureArray[i];
            if (!this._textureBuffer[texture.uid]) {
                this._textureBuffer[texture.uid] = texture;
                this._textureBufferLength += 1;
                const newLength = this._textureIndexedBuffer.push(texture);
                const index = newLength - 1;
                this._textureIndexMap[texture.uid] = index;
            }
        }
        return true;
    }
}
export default StdBatchFactory;
//# sourceMappingURL=StdBatchFactory.js.map